Package: vioplot
Title: Violin Plot
Version: 0.5.1
Date: 2025-02-24
Authors@R: c(person("Daniel", "Adler", email = "dadler@uni-goettingen.de", role = c("aut", "cph")),
           person("S. Thomas", "Kelly", email = "tomkellygenetics@gmail.com", role = c("aut", "cre")),
           person("Tom M.", "Elliott", email = "tom.elliott@auckland.ac.nz", role = c("aut", "ctb")),
           person("Jordan", "Adamson", email = "adamson@wifa.uni-leipzig.de", role = c("aut", "ctb")))
Description: A violin plot is a combination of a box plot and a kernel density plot. This package allows extensive customisation of violin plots. 
Depends: sm, zoo
License: BSD_3_clause + file LICENSE
URL: https://github.com/TomKellyGenetics/vioplot
BugReports: https://github.com/TomKellyGenetics/vioplot/issues
RoxygenNote: 7.3.2
Suggests: base, ggplot2, RColorBrewer, knitr, rmarkdown, testthat
Language: en-GB
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-02-23 20:25:10 UTC; kellyt
Author: Daniel Adler [aut, cph],
  S. Thomas Kelly [aut, cre],
  Tom M. Elliott [aut, ctb],
  Jordan Adamson [aut, ctb]
Maintainer: S. Thomas Kelly <tomkellygenetics@gmail.com>
Repository: CRAN
Date/Publication: 2025-02-23 23:40:02 UTC
Built: R 4.6.0; ; 2026-04-27 08:15:12 UTC; unix
