# Generated by roxygen2: do not edit by hand

S3method(histoplot,data.frame)
S3method(histoplot,default)
S3method(histoplot,formula)
S3method(histoplot,list)
S3method(histoplot,matrix)
S3method(vioplot,data.frame)
S3method(vioplot,default)
S3method(vioplot,formula)
S3method(vioplot,list)
S3method(vioplot,matrix)
S3method(vioplot,stats)
export(add_labels)
export(add_outliers)
export(histoplot)
export(vioplot)
import(sm)
importFrom(grDevices,boxplot.stats)
importFrom(grDevices,dev.flush)
importFrom(grDevices,dev.hold)
importFrom(grDevices,dev.interactive)
importFrom(grDevices,devAskNewPage)
importFrom(grDevices,xy.coords)
importFrom(graphics,Axis)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,plot.xy)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(zoo,rollmean)
